[Libreoffice-commits] core.git: sc/uiconfig

2018-10-12 Thread Libreoffice Gerrit user
 sc/uiconfig/scalc/ui/recalcquerydialog.ui |1 +
 1 file changed, 1 insertion(+)

New commits:
commit b9234b43ed259a10cf9077032af0f79740f01d8b
Author: Adolfo Jayme Barrientos 
AuthorDate: Sat Oct 13 01:27:41 2018 -0500
Commit: Adolfo Jayme Barrientos 
CommitDate: Sat Oct 13 01:27:41 2018 -0500

Fix a weird checkbox label in Calc’s recalculation prompt

GTK+’s dumb defaults strike again!

Similar to 7da61ec6d8ab6312b45ef7d683f3ec24e6b2b570.
Found while triaging tdf#120513.

Change-Id: I9ade695184cbcc9f1de9f11b20aa751754263586

diff --git a/sc/uiconfig/scalc/ui/recalcquerydialog.ui 
b/sc/uiconfig/scalc/ui/recalcquerydialog.ui
index 05c1ccc60ff0..04c185f63326 100644
--- a/sc/uiconfig/scalc/ui/recalcquerydialog.ui
+++ b/sc/uiconfig/scalc/ui/recalcquerydialog.ui
@@ -31,6 +31,7 @@
 True
 True
 False
+start
 True
 True
   
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: include/registry package/inc package/source postprocess/qa pyuno/source registry/source registry/tools

2018-10-12 Thread Libreoffice Gerrit user
 include/registry/refltype.hxx |   10 -
 package/inc/EncryptionData.hxx|   10 -
 package/inc/ZipFile.hxx   |2 -
 package/inc/ZipOutputEntry.hxx|2 -
 package/source/manifest/ManifestImport.hxx|4 +--
 package/source/xstor/ocompinstream.hxx|2 -
 package/source/xstor/owriteablestream.cxx |2 -
 package/source/xstor/owriteablestream.hxx |4 +--
 package/source/xstor/selfterminatefilestream.hxx  |2 -
 package/source/xstor/switchpersistencestream.cxx  |2 -
 package/source/xstor/xstorage.cxx |6 ++---
 package/source/xstor/xstorage.hxx |6 ++---
 package/source/zipapi/XBufferedThreadedStream.hxx |2 -
 package/source/zipapi/XUnbufferedStream.hxx   |2 -
 package/source/zippackage/ContentInfo.hxx |2 -
 postprocess/qa/services.cxx   |4 +--
 pyuno/source/module/pyuno_impl.hxx|4 +--
 registry/source/keyimpl.hxx   |2 -
 registry/source/reflread.cxx  |   14 ++--
 registry/source/reflwrit.cxx  |   24 +++---
 registry/tools/options.hxx|2 -
 21 files changed, 54 insertions(+), 54 deletions(-)

New commits:
commit 31138ff7729cbf179079a5e635d3a823e2971f08
Author: Noel Grandin 
AuthorDate: Fri Oct 12 14:48:15 2018 +0200
Commit: Noel Grandin 
CommitDate: Sat Oct 13 07:43:45 2018 +0200

loplugin:constfields in package..registry

Change-Id: Ie139490f2b008bf294910d002af711f8f41fe76d
Reviewed-on: https://gerrit.libreoffice.org/61727
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/include/registry/refltype.hxx b/include/registry/refltype.hxx
index ce8abb3a2c7c..5380a0de46bf 100644
--- a/include/registry/refltype.hxx
+++ b/include/registry/refltype.hxx
@@ -62,11 +62,11 @@ public:
  */
 struct RTUik
 {
-sal_uInt32 m_Data1;
-sal_uInt16 m_Data2;
-sal_uInt16 m_Data3;
-sal_uInt32 m_Data4;
-sal_uInt32 m_Data5;
+sal_uInt32 const m_Data1;
+sal_uInt16 const m_Data2;
+sal_uInt16 const m_Data3;
+sal_uInt32 const m_Data4;
+sal_uInt32 const m_Data5;
 };
 
 /// specifies the calling convention for type reader/writer api
diff --git a/package/inc/EncryptionData.hxx b/package/inc/EncryptionData.hxx
index c7c6ffb3555e..66f8aeb5881a 100644
--- a/package/inc/EncryptionData.hxx
+++ b/package/inc/EncryptionData.hxx
@@ -46,11 +46,11 @@ class EncryptionData : public BaseEncryptionData
 {
 public:
 css::uno::Sequence < sal_Int8 > m_aKey;
-sal_Int32 m_nEncAlg;
-sal_Int32 m_nCheckAlg;
-sal_Int32 m_nDerivedKeySize;
-sal_Int32 m_nStartKeyGenID;
-bool m_bTryWrongSHA1;
+sal_Int32 const m_nEncAlg;
+sal_Int32 const m_nCheckAlg;
+sal_Int32 const m_nDerivedKeySize;
+sal_Int32 const m_nStartKeyGenID;
+bool const m_bTryWrongSHA1;
 
 EncryptionData(const BaseEncryptionData& aData, const css::uno::Sequence< 
sal_Int8 >& aKey, sal_Int32 nEncAlg, sal_Int32 nCheckAlg, sal_Int32 
nDerivedKeySize, sal_Int32 nStartKeyGenID, bool const bTryWrongSHA1)
 : BaseEncryptionData( aData )
diff --git a/package/inc/ZipFile.hxx b/package/inc/ZipFile.hxx
index 3dceb036c3bd..58755d4ad2c7 100644
--- a/package/inc/ZipFile.hxx
+++ b/package/inc/ZipFile.hxx
@@ -62,7 +62,7 @@ class ZipFile
 css::uno::Reference < css::io::XInputStream > xStream;
 const css::uno::Reference < css::uno::XComponentContext > m_xContext;
 
-bool bRecoveryMode;
+bool const bRecoveryMode;
 
 // aMediaType parameter is used only for raw stream header creation
 css::uno::Reference < css::io::XInputStream >  createStreamForZipEntry(
diff --git a/package/inc/ZipOutputEntry.hxx b/package/inc/ZipOutputEntry.hxx
index d95ffd4969ab..15c94aecc14b 100644
--- a/package/inc/ZipOutputEntry.hxx
+++ b/package/inc/ZipOutputEntry.hxx
@@ -53,7 +53,7 @@ class ZipOutputEntry
 ZipEntry*m_pCurrentEntry;
 sal_Int16   m_nDigested;
 ZipPackageStream*   m_pCurrentStream;
-boolm_bEncryptCurrentEntry;
+bool const  m_bEncryptCurrentEntry;
 std::atomic   m_bFinished;
 
 public:
diff --git a/package/source/manifest/ManifestImport.hxx 
b/package/source/manifest/ManifestImport.hxx
index 19d426b14f25..33b0637015d7 100644
--- a/package/source/manifest/ManifestImport.hxx
+++ b/package/source/manifest/ManifestImport.hxx
@@ -36,8 +36,8 @@ typedef std::unordered_map< OUString, OUString > 
StringHashMap;
 
 struct ManifestScopeEntry
 {
-OUString m_aConvertedName;
-StringHashMap   m_aNamespaces;
+OUString const m_aConvertedName;
+StringHashMap const m_aNamespaces;
 boolm_bValid;
 
 ManifestScopeEntry( const OUString& aConvertedName, const StringHashMap& 
aNamespaces )
diff --git a/package/source/xstor/ocompinstream.hxx 
b/p

[Libreoffice-commits] core.git: Branch 'libreoffice-6-1' - dtrans/Library_mcnttype.mk dtrans/source

2018-10-12 Thread Libreoffice Gerrit user
 dtrans/Library_mcnttype.mk |1 
 dtrans/source/cnttype/mcnttype.cxx |  269 ++---
 dtrans/source/cnttype/mcnttype.hxx |3 
 3 files changed, 19 insertions(+), 254 deletions(-)

New commits:
commit 7ea7b86e7731f8cc1366ea632653fecc97267378
Author: Stephan Bergmann 
AuthorDate: Thu Oct 11 17:31:30 2018 +0200
Commit: Adolfo Jayme Barrientos 
CommitDate: Sat Oct 13 05:10:07 2018 +0200

tdf#120158: Base CMimeContentType on INetMIME::scanContentType

...instead of using yet another local implementation of parsing media types.

CMimeContentType is the implementation of the UNO
css.datatransfer.XMimeContentType interface.  One observable change in 
behavior
is that type, subtype, and parameter names will now always be reported in 
lower
case instead of with the casing from the input preserved (but those 
differences
in casing are functionally equivalent per the media type specification).  
Also,
parameter names supplied to the hasParameter and getParameterValue 
functions are
now also treated case-insensitive.

The upside of this change is that INetMIME::scanContentType (via "The 
encoding
of rMediaType should be US-ASCII, but any Unicode values in the range 
U+0080..
U+ are interpreted 'as appropriate.'") already implicitly supports RFC 
6532
"Internationalized Email Headers" extensions for media types, allowing 
quoted-
string parameter values to contain non-ASCII Unicode characters.

That means that tfd#120158 "Impossible to paste special in Writer from Calc 
in
Libreoffice 6.1.x in some UI languages - the dialogue caption says 'unknown
source'" can be fixed by just allowing non-ASCII typename parameters being
generated in ImplGetParameterString in svtools/source/misc/transfer.cxx, and
reverting the problematic (see the comments there) previous fix
 "tdf#120158: fix 
ImplGetParameterString
for typename".  (Which will be done in a follow-up commit, to ease potential
backporting, as that previous fix has already been backported to some 
versions
but not to others.)

Reviewed-on: https://gerrit.libreoffice.org/61684
Tested-by: Jenkins
Reviewed-by: Stephan Bergmann 
(cherry picked from commit b75e3ded1f73c943fb09f117e476e367ac0c3413)
Conflicts:
dtrans/source/cnttype/mcnttype.cxx

Change-Id: I5d4d3586e8046f288a97605b000e262a8db5a4e9
Reviewed-on: https://gerrit.libreoffice.org/61688
Tested-by: Jenkins
Reviewed-by: Adolfo Jayme Barrientos 

diff --git a/dtrans/Library_mcnttype.mk b/dtrans/Library_mcnttype.mk
index c139e88fed27..2442a01cb721 100644
--- a/dtrans/Library_mcnttype.mk
+++ b/dtrans/Library_mcnttype.mk
@@ -27,6 +27,7 @@ $(eval $(call gb_Library_use_libraries,mcnttype,\
cppu \
cppuhelper \
sal \
+   tl \
 ))
 
 $(eval $(call gb_Library_add_exception_objects,mcnttype,\
diff --git a/dtrans/source/cnttype/mcnttype.cxx 
b/dtrans/source/cnttype/mcnttype.cxx
index 3f982dd8a62c..483806163bea 100644
--- a/dtrans/source/cnttype/mcnttype.cxx
+++ b/dtrans/source/cnttype/mcnttype.cxx
@@ -20,20 +20,16 @@
 #include 
 
 #include 
+#include 
+#include 
 
 #include "mcnttype.hxx"
 
 using namespace com::sun::star::uno;
-using namespace com::sun::star::lang;
 using namespace com::sun::star::container;
 using namespace std;
 using namespace osl;
 
-const char TSPECIALS[] =  "()<>@,;:\\\"/[]?=";
-const char TOKEN[] = 
"!#$%&'*+-0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ^_`abcdefghijklmnopqrstuvwxyz{|}~.";
-const char SPACE[] = " ";
-const char SEMICOLON[] = ";";
-
 CMimeContentType::CMimeContentType( const OUString& aCntType )
 {
 init( aCntType );
@@ -75,267 +71,38 @@ Sequence< OUString > SAL_CALL 
CMimeContentType::getParameters( )
 sal_Bool SAL_CALL CMimeContentType::hasParameter( const OUString& aName )
 {
 MutexGuard aGuard( m_aMutex );
-return ( m_ParameterMap.end( ) != m_ParameterMap.find( aName ) );
+return ( m_ParameterMap.end( ) != m_ParameterMap.find( 
aName.toAsciiLowerCase() ) );
 }
 
 OUString SAL_CALL CMimeContentType::getParameterValue( const OUString& aName )
 {
+auto const lower = aName.toAsciiLowerCase();
+
 MutexGuard aGuard( m_aMutex );
 
-if ( !hasParameter( aName ) )
+if ( !hasParameter( lower ) )
 throw NoSuchElementException( );
 
-return m_ParameterMap.find( aName )->second;
+return m_ParameterMap.find( lower )->second;
 }
 
 void CMimeContentType::init( const OUString& aCntType )
 {
-if ( aCntType.isEmpty( ) )
-throw IllegalArgumentException( );
-
-m_nPos = 0;
-m_ContentType = aCntType;
-getSym( );
-type();
-}
-
-void CMimeContentType::getSym()
-{
-if ( m_nPos < m_ContentType.getLength( ) )
+INetContentTypeParameterList params;
+if (INetMIME::scanContentType(aCntType, &m_MediaType, &m_MediaSubtype, 
¶ms)
+!= aCntType.getStr() + aCnt

[Libreoffice-commits] core.git: icon-themes/karasa_jaga

2018-10-12 Thread Libreoffice Gerrit user
 dev/null|binary
 icon-themes/karasa_jaga/cmd/32/closedoc.png |binary
 icon-themes/karasa_jaga/cmd/32/closepreview.png |binary
 icon-themes/karasa_jaga/cmd/lc_closedoc.png |binary
 icon-themes/karasa_jaga/cmd/lc_closepreview.png |binary
 icon-themes/karasa_jaga/cmd/sc_closedoc.png |binary
 icon-themes/karasa_jaga/cmd/sc_closepreview.png |binary
 icon-themes/karasa_jaga/links.txt   |   13 +++--
 icon-themes/karasa_jaga/res/hldoctp.png |binary
 icon-themes/karasa_jaga/res/lx03125.png |binary
 icon-themes/karasa_jaga/res/mainapp_48_8.png|binary
 icon-themes/karasa_jaga/res/sx03125.png |binary
 12 files changed, 7 insertions(+), 6 deletions(-)

New commits:
commit 67bf520af2448e15802a5c0af977f3e1e7edb1bf
Author: Rizal Muttaqin 
AuthorDate: Fri Oct 5 20:07:26 2018 +0700
Commit: Adolfo Jayme Barrientos 
CommitDate: Sat Oct 13 04:54:48 2018 +0200

KJ: Change close doc icon, change some graphic icons

Change-Id: Ie6545844546dc78d14e1fabdf28f4e1938cf2dd6
Reviewed-on: https://gerrit.libreoffice.org/61420
Tested-by: Jenkins
Reviewed-by: Adolfo Jayme Barrientos 

diff --git a/icon-themes/karasa_jaga/cmd/32/closedoc.png 
b/icon-themes/karasa_jaga/cmd/32/closedoc.png
index fd500d9d151c..9198464625db 100644
Binary files a/icon-themes/karasa_jaga/cmd/32/closedoc.png and 
b/icon-themes/karasa_jaga/cmd/32/closedoc.png differ
diff --git a/icon-themes/karasa_jaga/cmd/32/closepreview.png 
b/icon-themes/karasa_jaga/cmd/32/closepreview.png
new file mode 100644
index ..fd500d9d151c
Binary files /dev/null and b/icon-themes/karasa_jaga/cmd/32/closepreview.png 
differ
diff --git a/icon-themes/karasa_jaga/cmd/lc_closedoc.png 
b/icon-themes/karasa_jaga/cmd/lc_closedoc.png
index 3cefcf24b7e4..c3acc1e75ae5 100644
Binary files a/icon-themes/karasa_jaga/cmd/lc_closedoc.png and 
b/icon-themes/karasa_jaga/cmd/lc_closedoc.png differ
diff --git a/icon-themes/karasa_jaga/cmd/lc_closepreview.png 
b/icon-themes/karasa_jaga/cmd/lc_closepreview.png
new file mode 100644
index ..3cefcf24b7e4
Binary files /dev/null and b/icon-themes/karasa_jaga/cmd/lc_closepreview.png 
differ
diff --git a/icon-themes/karasa_jaga/cmd/sc_closedoc.png 
b/icon-themes/karasa_jaga/cmd/sc_closedoc.png
index 5dad187ebea8..a5ad59bec461 100644
Binary files a/icon-themes/karasa_jaga/cmd/sc_closedoc.png and 
b/icon-themes/karasa_jaga/cmd/sc_closedoc.png differ
diff --git a/icon-themes/karasa_jaga/cmd/sc_closepreview.png 
b/icon-themes/karasa_jaga/cmd/sc_closepreview.png
new file mode 100644
index ..5dad187ebea8
Binary files /dev/null and b/icon-themes/karasa_jaga/cmd/sc_closepreview.png 
differ
diff --git a/icon-themes/karasa_jaga/links.txt 
b/icon-themes/karasa_jaga/links.txt
index 7ced2c701f4e..9c7d876c8409 100644
--- a/icon-themes/karasa_jaga/links.txt
+++ b/icon-themes/karasa_jaga/links.txt
@@ -48,7 +48,6 @@ cmd/32/charmapcontrol.png cmd/32/insertsymbol.png
 cmd/32/circle.png cmd/32/basicshapes.circle.png
 cmd/32/circlepie.png cmd/32/basicshapes.circle-pie.png
 cmd/32/closedocs.png cmd/32/closedoc.png
-cmd/32/closepreview.png cmd/32/closedoc.png
 cmd/32/columnoperations.png cmd/32/entirecolumn.png
 cmd/32/commentchange.png cmd/32/commentchangetracking.png
 cmd/32/commonalignbottom.png cmd/32/alignbottom.png
@@ -74,7 +73,7 @@ cmd/32/editpastespecialmenu.png cmd/32/pastespecial.png
 cmd/32/ellipse.png cmd/32/basicshapes.ellipse.png
 cmd/32/ellipsetoolbox.png cmd/32/basicshapes.ellipse.png
 cmd/32/es/underlinesimple.png cmd/32/es/underline.png
-cmd/32/exitsearch.png cmd/32/closedoc.png
+cmd/32/exitsearch.png cmd/32/closepreview.png
 cmd/32/fieldmenu.png cmd/32/insertfield.png
 cmd/32/fieldnames.png cmd/32/fields.png
 cmd/32/fillcolor.png cmd/32/formatarea.png
@@ -374,7 +373,6 @@ cmd/lc_charmapcontrol.png cmd/lc_insertsymbol.png
 cmd/lc_circle.png cmd/lc_basicshapes.circle.png
 cmd/lc_circlepie.png cmd/lc_basicshapes.circle-pie.png
 cmd/lc_closedocs.png cmd/lc_closedoc.png
-cmd/lc_closepreview.png cmd/lc_closedoc.png
 cmd/lc_columnoperations.png cmd/lc_entirecolumn.png
 cmd/lc_commentchange.png cmd/lc_commentchangetracking.png
 cmd/lc_commonalignbottom.png cmd/lc_alignbottom.png
@@ -399,7 +397,7 @@ cmd/lc_dsbeditdoc.png cmd/lc_editdoc.png
 cmd/lc_editpastespecialmenu.png cmd/lc_pastespecial.png
 cmd/lc_ellipse.png cmd/lc_basicshapes.ellipse.png
 cmd/lc_ellipsetoolbox.png cmd/lc_basicshapes.ellipse.png
-cmd/lc_exitsearch.png cmd/lc_closedoc.png
+cmd/lc_exitsearch.png cmd/lc_closepreview.png
 cmd/lc_fieldmenu.png cmd/lc_insertfield.png
 cmd/lc_fieldnames.png cmd/lc_fields.png
 cmd/lc_fillcolor.png cmd/lc_formatarea.png
@@ -649,7 +647,6 @@ cmd/sc_charmapcontrol.png cmd/sc_insertsymbol.png
 cmd/sc_circle.png cmd/sc_basicshapes.circle.png
 cmd/sc_circlepie.png cmd/sc_basicshapes.circle-pie.png
 cmd/sc_closedocs.png cmd/sc_closedoc.png
-cmd/sc_closepreview.png cmd/sc_closedoc.png
 cmd/sc_columnoperations.png cmd/sc_enti

[Libreoffice-commits] core.git: chart2/source chart2/uiconfig include/svx

2018-10-12 Thread Libreoffice Gerrit user
 chart2/source/controller/dialogs/TextDirectionListBox.cxx |   13 
 chart2/source/controller/dialogs/dlg_InsertDataLabel.cxx  |8 
 chart2/source/controller/dialogs/res_DataLabel.cxx|  220 ++
 chart2/source/controller/dialogs/res_DataLabel.hxx|   55 +--
 chart2/source/controller/dialogs/tp_DataLabel.cxx |   13 
 chart2/source/controller/dialogs/tp_DataLabel.hxx |2 
 chart2/source/controller/inc/TextDirectionListBox.hxx |7 
 chart2/source/controller/inc/dlg_InsertDataLabel.hxx  |   11 
 chart2/source/controller/main/ChartController_Insert.cxx  |6 
 chart2/uiconfig/ui/dlg_DataLabel.ui   |  172 --
 chart2/uiconfig/ui/tp_DataLabel.ui|  189 +++-
 include/svx/frmdirlbox.hxx|1 
 12 files changed, 292 insertions(+), 405 deletions(-)

New commits:
commit f7a2e12cb582bda905a75fc547ad632c9b371d06
Author: Caolán McNamara 
AuthorDate: Fri Oct 12 16:39:16 2018 +0100
Commit: Caolán McNamara 
CommitDate: Sat Oct 13 00:51:26 2018 +0200

weld DataLabelsDialog and DataLabelsTabPage

Change-Id: I509d58b2677b5e8f0db476e2650661cb128a5279
Reviewed-on: https://gerrit.libreoffice.org/61723
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 

diff --git a/chart2/source/controller/dialogs/TextDirectionListBox.cxx 
b/chart2/source/controller/dialogs/TextDirectionListBox.cxx
index 1fd5b7604c10..a622e2b651d2 100644
--- a/chart2/source/controller/dialogs/TextDirectionListBox.cxx
+++ b/chart2/source/controller/dialogs/TextDirectionListBox.cxx
@@ -42,6 +42,19 @@ TextDirectionListBox::TextDirectionListBox( vcl::Window* 
pParent ) :
 
 VCL_BUILDER_FACTORY(TextDirectionListBox)
 
+SchTextDirectionListBox::SchTextDirectionListBox(std::unique_ptr
 pControl)
+: svx::SvxFrameDirectionListBox(std::move(pControl))
+{
+append(SvxFrameDirection::Horizontal_LR_TB, 
SchResId(STR_TEXT_DIRECTION_LTR));
+append(SvxFrameDirection::Horizontal_RL_TB, 
SchResId(STR_TEXT_DIRECTION_RTL));
+append(SvxFrameDirection::Environment, SchResId(STR_TEXT_DIRECTION_SUPER));
+
+if (!SvtLanguageOptions().IsCTLFontEnabled())
+{
+hide();
+}
+}
+
 } //namespace chart
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/chart2/source/controller/dialogs/dlg_InsertDataLabel.cxx 
b/chart2/source/controller/dialogs/dlg_InsertDataLabel.cxx
index 4bfb943fddc9..57817d883d66 100644
--- a/chart2/source/controller/dialogs/dlg_InsertDataLabel.cxx
+++ b/chart2/source/controller/dialogs/dlg_InsertDataLabel.cxx
@@ -23,11 +23,9 @@
 namespace chart
 {
 
-DataLabelsDialog::DataLabelsDialog(vcl::Window* pWindow, const SfxItemSet& 
rInAttrs, SvNumberFormatter* pFormatter) :
-ModalDialog(pWindow
-,"dlg_DataLabels"
-,"modules/schart/ui/dlg_DataLabel.ui"),
-m_apDataLabelResources( new DataLabelResources(this, GetFrameWeld(), 
rInAttrs) )
+DataLabelsDialog::DataLabelsDialog(weld::Window* pWindow, const SfxItemSet& 
rInAttrs, SvNumberFormatter* pFormatter)
+: GenericDialogController(pWindow, "modules/schart/ui/dlg_DataLabel.ui", 
"dlg_DataLabels")
+, m_apDataLabelResources(new DataLabelResources(m_xBuilder.get(), pWindow, 
rInAttrs))
 {
 m_apDataLabelResources->SetNumberFormatter( pFormatter );
 m_apDataLabelResources->Reset(rInAttrs);
diff --git a/chart2/source/controller/dialogs/res_DataLabel.cxx 
b/chart2/source/controller/dialogs/res_DataLabel.cxx
index 95094b4b8d8a..e44a346a0a46 100644
--- a/chart2/source/controller/dialogs/res_DataLabel.cxx
+++ b/chart2/source/controller/dialogs/res_DataLabel.cxx
@@ -69,65 +69,54 @@ bool lcl_ReadNumberFormatFromItemSet( const SfxItemSet& 
rSet, sal_uInt16 nValueW
 return bSet;
 }
 
-void lcl_setBoolItemToCheckBox( const SfxItemSet& rInAttrs, sal_uInt16 
nWhichId, CheckBox& rCheckbox )
+void lcl_setBoolItemToCheckBox(const SfxItemSet& rInAttrs, sal_uInt16 
nWhichId, weld::CheckButton& rCheckbox)
 {
-rCheckbox.EnableTriState( false );
-
 const SfxPoolItem *pPoolItem = nullptr;
 if( rInAttrs.GetItemState(nWhichId, true, &pPoolItem) == SfxItemState::SET 
)
-rCheckbox.Check( static_cast(pPoolItem)->GetValue() );
+rCheckbox.set_active(static_cast(pPoolItem)->GetValue());
 else
-{
-rCheckbox.EnableTriState();
-rCheckbox.SetState( TRISTATE_INDET );
-}
+rCheckbox.set_state(TRISTATE_INDET);
 }
 
 }//end anonymous namespace
 
-DataLabelResources::DataLabelResources(VclBuilderContainer* pWindow, 
weld::Window* pParent, const SfxItemSet& rInAttrs )
-:
-m_pNumberFormatter(nullptr),
-m_bNumberFormatMixedState(true),
-m_bPercentFormatMixedState(true),
-m_nNumberFormatForValue(0),
-m_nNumberFormatForPercent(11),
-m_bSourceFormatMixedState(true),
-m_bPercentSourceMixedState(true),
-m_bSourceFormatForValue(true),
-m_bSourceFormatForPercent(true),
-

[Libreoffice-commits] core.git: dbaccess/Library_dba.mk dbaccess/source solenv/clang-format

2018-10-12 Thread Libreoffice Gerrit user
 dbaccess/Library_dba.mk|1 
 dbaccess/source/core/dataaccess/ModelImpl.cxx  |1 
 dbaccess/source/core/dataaccess/datasource.cxx |1 
 dbaccess/source/core/inc/userinformation.hxx   |   39 -
 dbaccess/source/core/misc/userinformation.cxx  |   33 -
 solenv/clang-format/blacklist  |2 -
 6 files changed, 77 deletions(-)

New commits:
commit c0bf396a566f94b0999357dcdca10cf2eb03b5bc
Author: Eike Rathke 
AuthorDate: Fri Oct 12 22:38:31 2018 +0200
Commit: Eike Rathke 
CommitDate: Sat Oct 13 00:33:16 2018 +0200

Ditch now unused class UserInformation and userinformation.?xx

... one class with one member variable holding one string for one
instantiation ...

Change-Id: I033312ed1c05c181e7077b4b1a0d988cfb80eb33
Reviewed-on: https://gerrit.libreoffice.org/61734
Reviewed-by: Eike Rathke 
Tested-by: Jenkins

diff --git a/dbaccess/Library_dba.mk b/dbaccess/Library_dba.mk
index fe80f157887b..126f3a77211d 100644
--- a/dbaccess/Library_dba.mk
+++ b/dbaccess/Library_dba.mk
@@ -121,7 +121,6 @@ $(eval $(call gb_Library_add_exception_objects,dba,\
 dbaccess/source/core/misc/PropertyForward \
 dbaccess/source/core/misc/sdbcoretools \
 dbaccess/source/core/misc/services \
-dbaccess/source/core/misc/userinformation \
 dbaccess/source/core/misc/veto \
 dbaccess/source/core/recovery/dbdocrecovery \
 dbaccess/source/core/recovery/settingsimport \
diff --git a/dbaccess/source/core/dataaccess/ModelImpl.cxx 
b/dbaccess/source/core/dataaccess/ModelImpl.cxx
index 64bc6b16e8bd..4f360bfc1ee9 100644
--- a/dbaccess/source/core/dataaccess/ModelImpl.cxx
+++ b/dbaccess/source/core/dataaccess/ModelImpl.cxx
@@ -24,7 +24,6 @@
 #include "datasource.hxx"
 #include 
 #include 
-#include 
 #include 
 
 #include 
diff --git a/dbaccess/source/core/dataaccess/datasource.cxx 
b/dbaccess/source/core/dataaccess/datasource.cxx
index fd707eb1cb66..b653396e54e7 100644
--- a/dbaccess/source/core/dataaccess/datasource.cxx
+++ b/dbaccess/source/core/dataaccess/datasource.cxx
@@ -18,7 +18,6 @@
  */
 
 #include "datasource.hxx"
-#include 
 #include "commandcontainer.hxx"
 #include 
 #include 
diff --git a/dbaccess/source/core/inc/userinformation.hxx 
b/dbaccess/source/core/inc/userinformation.hxx
deleted file mode 100644
index 4a8243686eeb..
--- a/dbaccess/source/core/inc/userinformation.hxx
+++ /dev/null
@@ -1,39 +0,0 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*
- * This file is part of the LibreOffice project.
- *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- *
- * This file incorporates work covered by the following license notice:
- *
- *   Licensed to the Apache Software Foundation (ASF) under one or more
- *   contributor license agreements. See the NOTICE file distributed
- *   with this work for additional information regarding copyright
- *   ownership. The ASF licenses this file to you under the Apache
- *   License, Version 2.0 (the "License"); you may not use this file
- *   except in compliance with the License. You may obtain a copy of
- *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
- */
-
-#ifndef INCLUDED_DBACCESS_SOURCE_CORE_INC_USERINFORMATION_HXX
-#define INCLUDED_DBACCESS_SOURCE_CORE_INC_USERINFORMATION_HXX
-
-#include 
-
-#include 
-
-class UserInformation
-{
-css::lang::Locale  m_aUserLocale;
-
-public:
-UserInformation();
-
-const css::lang::Locale& getUserLanguage() const { return m_aUserLocale; }
-};
-
-#endif // INCLUDED_DBACCESS_SOURCE_CORE_INC_USERINFORMATION_HXX
-
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/dbaccess/source/core/misc/userinformation.cxx 
b/dbaccess/source/core/misc/userinformation.cxx
deleted file mode 100644
index b5f6d4e28f88..
--- a/dbaccess/source/core/misc/userinformation.cxx
+++ /dev/null
@@ -1,33 +0,0 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*
- * This file is part of the LibreOffice project.
- *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- *
- * This file incorporates work covered by the following license notice:
- *
- *   Licensed to the Apache Software Foundation (ASF) under one or more
- *   contributor license agreements. See the NOTICE file distributed
- *   with this work for additional information regarding copyright
- *   ownership. The ASF licenses this file to you under the Apache
- *   License, Version 2.0 (the "License"); you may not use this file
- *   except in compliance with the License. You may obtain a copy of
- *   the License at http://www.apache.o

[Libreoffice-commits] core.git: dbaccess/source

2018-10-12 Thread Libreoffice Gerrit user
 dbaccess/source/core/dataaccess/ModelImpl.cxx |6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit e888ed185e9e4b254409959c7978e4d84f70d846
Author: Eike Rathke 
AuthorDate: Fri Oct 12 22:27:07 2018 +0200
Commit: Eike Rathke 
CommitDate: Sat Oct 13 00:05:35 2018 +0200

Extract the one getUserLanguage() call from UserInformation

After which we can ditch that.

Change-Id: I6027327b41d98bffd47324b4c6145c1eddca632a
Reviewed-on: https://gerrit.libreoffice.org/61733
Reviewed-by: Eike Rathke 
Tested-by: Jenkins

diff --git a/dbaccess/source/core/dataaccess/ModelImpl.cxx 
b/dbaccess/source/core/dataaccess/ModelImpl.cxx
index abdd5242d27a..64bc6b16e8bd 100644
--- a/dbaccess/source/core/dataaccess/ModelImpl.cxx
+++ b/dbaccess/source/core/dataaccess/ModelImpl.cxx
@@ -55,6 +55,7 @@
 #include 
 #include 
 #include 
+#include 
 
 #include 
 
@@ -690,9 +691,8 @@ const Reference< XNumberFormatsSupplier > & 
ODatabaseModelImpl::getNumberFormats
 {
 if (!m_xNumberFormatsSupplier.is())
 {
-// the arguments : the locale of the current user
-UserInformation aUserInfo;
-Locale aLocale = aUserInfo.getUserLanguage();
+// the arguments : the work locale of the current user
+Locale aLocale( LanguageTag::convertToLocale( 
utl::ConfigManager::getWorkLocale(), false));
 
 m_xNumberFormatsSupplier.set( NumberFormatsSupplier::createWithLocale( 
m_aContext, aLocale ) );
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Re: how to set JAVA_HOME

2018-10-12 Thread Luke Benes
I first noticed this same error in Arch after a Java version upgrade. Then 
again after I upgraded Ubuntu from 16.04 to 180.4. 

My guess is that either this is an error in our autogen.sh Java detection logic 
or there was a change in the Java installer between Java 8 and Java 10.
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: svl/source

2018-10-12 Thread Libreoffice Gerrit user
 svl/source/numbers/supservs.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit d77446f12b2f72a208edcb4765b38a7e30c70962
Author: Eike Rathke 
AuthorDate: Fri Oct 12 19:24:09 2018 +0200
Commit: Eike Rathke 
CommitDate: Fri Oct 12 22:25:02 2018 +0200

SvNumberFormatsSupplierServiceObject: default to LANGUAGE_SYSTEM

... instead of LANGUAGE_ENGLISH_US that will be ultimate fall-back
anyway if no match is found.

Change-Id: Ice6495e54fa0a1e275769fcfdf1e0e932e22944e
Reviewed-on: https://gerrit.libreoffice.org/61729
Reviewed-by: Eike Rathke 
Tested-by: Eike Rathke 

diff --git a/svl/source/numbers/supservs.cxx b/svl/source/numbers/supservs.cxx
index 8fc748c6d4a1..1188f6b0b784 100644
--- a/svl/source/numbers/supservs.cxx
+++ b/svl/source/numbers/supservs.cxx
@@ -75,7 +75,7 @@ void SAL_CALL 
SvNumberFormatsSupplierServiceObject::initialize( const Sequence<
 }
 
 Type aExpectedArgType = ::cppu::UnoType::get();
-LanguageType eNewFormatterLanguage = LANGUAGE_ENGLISH_US;
+LanguageType eNewFormatterLanguage = LANGUAGE_SYSTEM;
 // the default
 
 const Any* pArgs = _rArguments.getConstArray();
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: svtools/source

2018-10-12 Thread Libreoffice Gerrit user
 svtools/source/control/fmtfield.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit da4dc534403b74182913cc4dfeb2b689a30e513c
Author: Eike Rathke 
AuthorDate: Fri Oct 12 18:33:00 2018 +0200
Commit: Eike Rathke 
CommitDate: Fri Oct 12 22:19:26 2018 +0200

Resolves: tdf#119739 switch date field input to 
NF_EVALDATEFORMAT_FORMAT_INTL

To evaluate date input against date acceptance patterns in the
order first format locale, if any, then formatter (system) locale.

The slight drawback is when the field has no content there is no
indication of that the format's locale's patterns would be
preferred, whereas the old NF_EVALDATEFORMAT_INTL_FORMAT preferred
the default locale's patterns.

The big advantage is that editing a date actually uses the
patterns associated with the presented display string.

Change-Id: Id3f11e26a0e32b95f26b69a681433deb87b7c6b0
Reviewed-on: https://gerrit.libreoffice.org/61726
Reviewed-by: Eike Rathke 
Tested-by: Jenkins

diff --git a/svtools/source/control/fmtfield.cxx 
b/svtools/source/control/fmtfield.cxx
index 8a718876eb7b..08d10c781eba 100644
--- a/svtools/source/control/fmtfield.cxx
+++ b/svtools/source/control/fmtfield.cxx
@@ -699,7 +699,7 @@ void FormattedField::FormatChanged( FORMAT_CHANGE_TYPE 
_nWhat )
 m_pLastOutputColor = nullptr;
 
 if ( (_nWhat == FORMAT_CHANGE_TYPE::FORMATTER) && m_pFormatter )
-m_pFormatter->SetEvalDateFormat( NF_EVALDATEFORMAT_INTL_FORMAT );
+m_pFormatter->SetEvalDateFormat( NF_EVALDATEFORMAT_FORMAT_INTL );
 
 ReFormat();
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sw/source

2018-10-12 Thread Libreoffice Gerrit user
 sw/source/core/txtnode/fntcache.cxx |   13 ++---
 1 file changed, 10 insertions(+), 3 deletions(-)

New commits:
commit c7b83934fcf4120c1a4cba8e1eaf9c7aef9edc82
Author: Miklos Vajna 
AuthorDate: Fri Oct 12 17:57:36 2018 +0200
Commit: Miklos Vajna 
CommitDate: Fri Oct 12 20:38:31 2018 +0200

tdf#119992 sw: compare sub-strings in SwTextGlyphsKey comparison

Time till the layout reaches idle, before:

77.412 seconds

After:

26.221 seconds (33% of baseline) for me.

Change-Id: Idd0c5255070c836fde2fb048b02c851f5f2321e4
Reviewed-on: https://gerrit.libreoffice.org/61724
Reviewed-by: Miklos Vajna 
Tested-by: Jenkins

diff --git a/dbaccess/source/core/misc/userinformation.cxx 
b/dbaccess/source/core/misc/userinformation.cxx
index d7cd482f4a80..b5f6d4e28f88 100644
--- a/dbaccess/source/core/misc/userinformation.cxx
+++ b/dbaccess/source/core/misc/userinformation.cxx
@@ -27,7 +27,7 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
 
 UserInformation::UserInformation():
-m_aUserLocale( LanguageTag( ConfigManager::getLocale()).getLocale())
+m_aUserLocale( LanguageTag( ConfigManager::getWorkLocale()).getLocale())
 {}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/desktop/source/app/app.cxx b/desktop/source/app/app.cxx
index de11310bc7ca..bbe4b2ee286d 100644
--- a/desktop/source/app/app.cxx
+++ b/desktop/source/app/app.cxx
@@ -1998,7 +1998,7 @@ void Desktop::OpenClients()
 OUString aHelpURL = "vnd.sun.star.help://"
   + aHelpModule
   + "/start?Language="
-  + utl::ConfigManager::getLocale();
+  + utl::ConfigManager::getUILocale();
 #if defined UNX
 aHelpURL += "&System=UNX";
 #elif defined WNT
diff --git a/desktop/source/app/officeipcthread.cxx 
b/desktop/source/app/officeipcthread.cxx
index a606c589bcc8..49a08f97eeb8 100644
--- a/desktop/source/app/officeipcthread.cxx
+++ b/desktop/source/app/officeipcthread.cxx
@@ -1086,7 +1086,7 @@ bool IpcThread::process(OString const & arguments, bool * 
waitProcessed) {
 }
 if (bShowHelp) {
 aHelpURLBuffer.append("?Language=");
-aHelpURLBuffer.append(utl::ConfigManager::getLocale());
+aHelpURLBuffer.append(utl::ConfigManager::getUILocale());
 #if defined UNX
 aHelpURLBuffer.append("&System=UNX");
 #elif defined WNT
diff --git a/desktop/source/deployment/misc/dp_resource.cxx 
b/desktop/source/deployment/misc/dp_resource.cxx
index 4f5671df9879..c6e9d2a18e3a 100644
--- a/desktop/source/deployment/misc/dp_resource.cxx
+++ b/desktop/source/deployment/misc/dp_resource.cxx
@@ -37,7 +37,7 @@ namespace {
 struct OfficeLocale :
 public rtl::StaticWithInit {
 const LanguageTag operator () () {
-OUString slang(utl::ConfigManager::getLocale());
+OUString slang(utl::ConfigManager::getUILocale());
 //fallback, the locale is currently only set when the user starts the
 //office for the first time.
 if (slang.isEmpty())
diff --git a/desktop/source/pkgchk/unopkg/unopkg_cmdenv.cxx 
b/desktop/source/pkgchk/unopkg/unopkg_cmdenv.cxx
index 96b086878f58..e7f8a2927806 100644
--- a/desktop/source/pkgchk/unopkg/unopkg_cmdenv.cxx
+++ b/desktop/source/pkgchk/unopkg/unopkg_cmdenv.cxx
@@ -155,7 +155,7 @@ void CommandEnvironmentImpl::printLicense(
 Reference< css::i18n::XCollator > xCollator =
 css::i18n::Collator::create( m_xComponentContext );
 xCollator->loadDefaultCollator(
-LanguageTag(utl::ConfigManager::getLocale()).getLocale(),
+LanguageTag(utl::ConfigManager::getUILocale()).getLocale(),
 css::i18n::CollatorOptions::CollatorOptions_IGNORE_CASE);
 
 do
diff --git a/framework/source/services/substitutepathvars.cxx 
b/framework/source/service

[Libreoffice-commits] core.git: Branch 'private/mst/sw_redlinehide_3' - 33 commits - editeng/source sw/inc sw/source vcl/unx

2018-10-12 Thread Libreoffice Gerrit user
Rebased ref, commits from common ancestor:
commit 61ea78e3bb86f3624748758f9038dc99abddaffc
Author: Michael Stahl 
AuthorDate: Fri Oct 12 16:33:00 2018 +0200
Commit: Michael Stahl 
CommitDate: Fri Oct 12 18:20:19 2018 +0200

sw_redlinehide_3: fix crash when storing clipboard document

It doesn't have a layout, of course.

Change-Id: Iec4809ec4a14e1fa9852d09619a8b344419b29e7

diff --git a/sw/source/filter/xml/wrtxml.cxx b/sw/source/filter/xml/wrtxml.cxx
index df75d14868db..0d5e53d4c319 100644
--- a/sw/source/filter/xml/wrtxml.cxx
+++ b/sw/source/filter/xml/wrtxml.cxx
@@ -189,7 +189,8 @@ ErrCode SwXMLWriter::Write_( const uno::Reference < 
task::XStatusIndicator >& xS
 bool isShowChanges;
 if (officecfg::Office::Common::Misc::ExperimentalMode::get(xContext))
 {   // TODO: ideally this would be stored per-view...
-isShowChanges = 
!m_pDoc->getIDocumentLayoutAccess().GetCurrentLayout()->IsHideRedlines();
+SwRootFrame const*const 
pLayout(m_pDoc->getIDocumentLayoutAccess().GetCurrentLayout());
+isShowChanges = pLayout == nullptr || !pLayout->IsHideRedlines();
 }
 else
 {
commit 8296be7ce488dbcef65a2332c3cebdeb6e70c06c
Author: Michael Stahl 
AuthorDate: Fri Oct 12 16:31:31 2018 +0200
Commit: Michael Stahl 
CommitDate: Fri Oct 12 18:20:19 2018 +0200

sw_redlinehide_3: fix SwAttrIter::SeekFwd()

This never called Rst() in the loops because the m_nPosition wasn't updated.

Change-Id: I5a9cf47d9fe6d92bb7fccf255acbbd22f04b7f47

diff --git a/sw/source/core/text/itratr.cxx b/sw/source/core/text/itratr.cxx
index 0533fae9be27..18145cb38523 100644
--- a/sw/source/core/text/itratr.cxx
+++ b/sw/source/core/text/itratr.cxx
@@ -260,7 +260,7 @@ bool SwAttrIter::SeekStartAndChgAttrIter( OutputDevice* 
pOut, const bool bParaFo
 }
 
 // AMA: New AttrIter Nov 94
-void SwAttrIter::SeekFwd( const sal_Int32 nNewPos )
+void SwAttrIter::SeekFwd(const sal_Int32 nOldPos, const sal_Int32 nNewPos)
 {
 SwpHints const*const pHints(m_pTextNode->GetpSwpHints());
 SwTextAttr *pTextAttr;
@@ -276,7 +276,7 @@ void SwAttrIter::SeekFwd( const sal_Int32 nNewPos )
 {
 // Close the TextAttributes, whose StartPos were before or at
 // the old nPos and are currently open
-if (pTextAttr->GetStart() <= m_nPosition)  Rst( pTextAttr );
+if (pTextAttr->GetStart() <= nOldPos)  Rst( pTextAttr );
 m_nEndIndex++;
 }
 }
@@ -320,14 +320,15 @@ bool SwAttrIter::Seek(TextFrameIndex const nNewPos)
 sal_Int32 nPos(m_nPosition);
 do
 {
+sal_Int32 const nOldPos(nPos);
 nPos = GetNextAttrImpl(m_pTextNode, m_nStartIndex, 
m_nEndIndex, nPos);
 if (nPos <= m_pTextNode->Len())
 {
-SeekFwd(nPos);
+SeekFwd(nOldPos, nPos);
 }
 else
 {
-SeekFwd(m_pTextNode->Len());
+SeekFwd(nOldPos, m_pTextNode->Len());
 }
 }
 while (nPos < m_pTextNode->Len());
@@ -399,21 +400,22 @@ bool SwAttrIter::Seek(TextFrameIndex const nNewPos)
 sal_Int32 nPos(m_nPosition);
 do
 {
+sal_Int32 const nOldPos(nPos);
 nPos = GetNextAttrImpl(m_pTextNode, m_nStartIndex, 
m_nEndIndex, nPos);
 if (nPos <= newPos.second)
 {
-SeekFwd(nPos);
+SeekFwd(nOldPos, nPos);
 }
 else
 {
-SeekFwd(newPos.second);
+SeekFwd(nOldPos, newPos.second);
 }
 }
 while (nPos < newPos.second);
 }
 else
 {
-SeekFwd(newPos.second);
+SeekFwd(m_nPosition, newPos.second);
 }
 }
 
diff --git a/sw/source/core/text/itratr.hxx b/sw/source/core/text/itratr.hxx
index 99741c87b965..959436609608 100644
--- a/sw/source/core/text/itratr.hxx
+++ b/sw/source/core/text/itratr.hxx
@@ -63,7 +63,7 @@ private:
 const SwTextNode* m_pTextNode;
 sw::MergedPara const* m_pMergedPara;
 
-void SeekFwd( const sal_Int32 nPos );
+void SeekFwd(sal_Int32 nOldPos, sal_Int32 nNewPos);
 void SetFnt( SwFont* pNew ) { m_pFont = pNew; }
 void InitFontAndAttrHandler(SwTextNode const& rTextNode,
 OUString const& rText, bool const* pbVertLayout);
commit 99b2a972c189d279e0a9b3462ec7e621d6a60c45
Author: Michael Stahl 
AuthorDate: Fri Oct 12 15:06:35 2018 +0200
Commit: Michael Stahl 
CommitDate: Fri Oct 12 18:20:19 2018 +0200

sw_redlinehide_3: fix SwAccessibleParagraph::getRunAttributes() index

... check, which should accept the past-the-last-char index, because
as the comments say it returns the hard attributes of the SwTextNode
as well, so it should wo

[Libreoffice-commits] core.git: toolkit/source

2018-10-12 Thread Libreoffice Gerrit user
 toolkit/source/helper/unowrapper.cxx |6 +-
 1 file changed, 1 insertion(+), 5 deletions(-)

New commits:
commit 5d5e0da5c314773129d8153363e2892fc359a744
Author: Caolán McNamara 
AuthorDate: Fri Oct 12 14:35:59 2018 +0100
Commit: Caolán McNamara 
CommitDate: Fri Oct 12 17:47:08 2018 +0200

tdf#118572 dispose instead of LazyDeletor

Change-Id: Ib52a1d6ffee0354cc7749f2535a05821d73149c5
Reviewed-on: https://gerrit.libreoffice.org/61716
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 

diff --git a/toolkit/source/helper/unowrapper.cxx 
b/toolkit/source/helper/unowrapper.cxx
index f0e2c2dc0e66..f838fa57694b 100644
--- a/toolkit/source/helper/unowrapper.cxx
+++ b/toolkit/source/helper/unowrapper.cxx
@@ -288,11 +288,7 @@ void UnoWrapper::WindowDestroyed( vcl::Window* pWindow )
 
 VclPtr< vcl::Window > pNextTopChild = pTopWindowChild->GetWindow( 
GetWindowType::NextTopWindowSibling );
 
-//the window still could be on the stack, so we have to
-// use lazy delete ( it will automatically
-// disconnect from the currently destroyed parent window )
-pTopWindowChild->doLazyDelete();
-
+pTopWindowChild.disposeAndClear();
 pTopWindowChild = pNextTopChild;
 }
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] online.git: 2 commits - loleaflet/dist test/TileCacheTests.cpp wsd/DocumentBroker.cpp wsd/TileCache.cpp wsd/TileCache.hpp

2018-10-12 Thread Libreoffice Gerrit user
 loleaflet/dist/framed.doc.html |   85 +
 test/TileCacheTests.cpp|2 
 wsd/DocumentBroker.cpp |2 
 wsd/TileCache.cpp  |   13 --
 wsd/TileCache.hpp  |4 +
 5 files changed, 99 insertions(+), 7 deletions(-)

New commits:
commit 7563490fd43ceb32a3083ff5a4eb177156a96d53
Author: Ashod Nakashian 
AuthorDate: Fri Jul 27 00:16:50 2018 -0400
Commit: Jan Holesovsky 
CommitDate: Fri Oct 12 17:43:40 2018 +0200

leaflet: new sample iframe html

This loads a writer doc and demonstrates the
use of Capitalise.py and InsertText.py.

Change-Id: I4a200eff54b697b1179627b49c27961edf188e59

diff --git a/loleaflet/dist/framed.doc.html b/loleaflet/dist/framed.doc.html
new file mode 100644
index 0..8fa875db4
--- /dev/null
+++ b/loleaflet/dist/framed.doc.html
@@ -0,0 +1,85 @@
+
+
+
+
+
+  
+
+Online Editor
+
+
+
+  function insertText(text) {
+window.frames[0].postMessage(JSON.stringify({'MessageId': 
'Host_PostmessageReady'}), '*');
+window.frames[0].postMessage(JSON.stringify({'MessageId': 
'CallPythonScript',
+ 'SendTime': Date.now(),
+ 'ScriptFile': 
'InsertText.py',
+ 'Function': 'InsertText',
+ 'Values': { 'text': 
{'type': 'string', 'value': text}}
+ }),
+ '*');
+  }
+
+  function capitalize() {
+window.frames[0].postMessage(JSON.stringify({'MessageId': 
'Host_PostmessageReady'}), '*');
+window.frames[0].postMessage(JSON.stringify({'MessageId': 
'CallPythonScript',
+ 'SendTime': Date.now(),
+ 'ScriptFile': 
'Capitalise.py',
+ 'Function': 
'capitalisePython',
+ 'Values': null
+ }),
+ '*');
+  }
+
+  // This function is invoked when the iframe posts a message back.
+
+  function receiveMessage(event) {
+var msg = JSON.parse(event.data);
+console.log(' framed.html receiveMessage: ' + event.data);
+console.log(' ' + msg);
+  }
+
+  // 'main' code of this
diff --git a/sw/source/core/txtnode/fntcache.cxx 
b/sw/source/core/txtnode/fntcache.cxx
index 740710c6c27e..9166965dfb7e 100644
--- a/sw/source/core/txtnode/fntcache.cxx
+++ b/sw/source/core/txtnode/fntcache.cxx
@@ -144,9 +144,16 @@ bool operator<(const SwTextGlyphsKey& l, const 
SwTextGlyphsKey& r)
 if (l.m_nLength > r.m_nLength)
 return false;
 
-// Comparing strings is expensive, so compare them only at the end, and
-// only once.
-sal_Int32 nRet = l.m_aText.compareTo(r.m_aText);
+// Comparing strings is expensive, so compare them:
+// - only at the end of this function
+// - only once
+// - only the relevant substring (if the index/length is not out of bounds)
+sal_Int32 nRet = 0;
+if (l.m_nLength < 0 || l.m_nIndex < 0 || l.m_nIndex + l.m_nLength > 
l.m_aText.getLength())
+nRet = l.m_aText.compareTo(r.m_aText);
+else
+nRet = memcmp(l.m_aText.getStr() + l.m_nIndex, r.m_aText.getStr() + 
r.m_nIndex,
+  l.m_nLength * sizeof(sal_Unicode));
 if (nRet < 0)
 return true;
 if (nRet > 0)
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: dbaccess/source desktop/source framework/source include/unotools sfx2/source svx/source unotools/source

2018-10-12 Thread Libreoffice Gerrit user
 dbaccess/source/core/misc/userinformation.cxx|2 +-
 desktop/source/app/app.cxx   |2 +-
 desktop/source/app/officeipcthread.cxx   |2 +-
 desktop/source/deployment/misc/dp_resource.cxx   |2 +-
 desktop/source/pkgchk/unopkg/unopkg_cmdenv.cxx   |2 +-
 framework/source/services/substitutepathvars.cxx |2 +-
 include/unotools/configmgr.hxx   |4 +++-
 sfx2/source/appl/appserv.cxx |   12 ++--
 sfx2/source/appl/sfxhelp.cxx |4 ++--
 sfx2/source/doc/doctemplates.cxx |2 +-
 sfx2/source/view/viewfrm.cxx |2 +-
 svx/source/dialog/SafeModeDialog.cxx |2 +-
 unotools/source/config/configmgr.cxx |8 +++-
 13 files changed, 27 insertions(+), 19 deletions(-)

New commits:
commit e30f6a8c6b053e7a7b9c54fb3fdaed4e73bb5389
Author: Eike Rathke 
AuthorDate: Fri Oct 12 17:39:14 2018 +0200
Commit: Eike Rathke 
CommitDate: Fri Oct 12 19:25:14 2018 +0200

tdf#119739 split ConfigManager::getLocale(), getUILocale(), getWorkLocale()

To prevent further confusion which is which, dbaccess
UserInformation already got that wrong since ever.

/org.openoffice.Setup/L10N/ooLocale is the UI locale.
/org.openoffice.Setup/L10N/ooSetupSystemLocale is the work locale.

Confusingly due to legacy when the setup program was a separate
binary that picked the UI ooLocale and later set up the default
(system) work locale as well.

Change-Id: I9a05ad39f5fb65c54076ff5789ba7a2cc06ad23a
Reviewed-on: https://gerrit.libreoffice.org/61725
Reviewed-by: Eike Rathke 
Tested-by: Jenkins
